<?php
/**
 * Report field factory class for Max Media Manager
 *
 * @since 0.3.19 - Mar 13, 2006
 * @copyright 2006 M3 Media Services
 * @version $Id: FieldFactory.php 4441 2006-03-13 15:14:59Z roh@m3.net $
 */

require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/TextField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/CampaignIdField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/AdvertiserIdField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/PublisherIdField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/TrackerField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/ZoneIdField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/ZoneScopeField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/DateRangeField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/DateRangeSelectorField.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field/ScopeSelectionField.php';

class FieldFactory
{
     /**
      *  Creates a new Field object of the appropriate subclass.
      */
    function &newField($field_type)
    {
        // Text field
        if ($field_type == 'edit')
        {
            $product = new TextField();
        }

        // CampaignID-dropdown
        elseif ($field_type == 'campaignid-dropdown')
        {
            $product = new CampaignIdField();
        }

        // ClientID-dropdown
        elseif ($field_type == 'clientid-dropdown' || $field_type == 'advertiser')
        {
            $product = new AdvertiserIdField();
        }

        // AffiliateID-dropdown
        elseif ($field_type == 'affiliateid-dropdown' || $field_type == 'publisher')
        {
            $product = new PublisherIdField();
        }

        // Tracker-dropdown
        elseif ($field_type == 'trackerid-dropdown') {
            $product = new TrackerField();
        }

        // ZoneID-dropdown
        elseif ($field_type == 'zoneid-dropdown')
        {
            $product = new ZoneIdField();
        }

        elseif ($field_type == 'zone-scope')
        {
            $product = new ZoneScopeField();
        }

        elseif ($field_type == 'date-range' || $field_type == 'date-month')
        {
            $product = new DateRangeField(new Date());
        }

        elseif ($field_type == 'date-range-selector')
        {
            $product = new DateRangeSelectorField();
        }

        elseif ($field_type == 'scope')
        {
            $product = new ScopeSelectionField();
        }

        else
        {
            MAX::raiseError("The report module discovered a field type that it didn't know how to handle.", MAX_ERROR_INVALIDARGS);
        }

        $product->tabindex = 0;
        $product->tabkeeper =& $product;

        return $product;
    }
}

?>
