<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Plugin.plg.test.php 4447 2006-03-13 17:09:14Z andrew@m3.net $
*/

/**
 * @package    MaxPlugins
 * @subpackage TestSuite
 * @author     Radek Maciaszek <radek@m3.net>
 */

    class TestErrorHandler {
        function handleErrors() {
        }
    }

    require_once(MAX_PATH . '/lib/max/Plugin.php');

    define('MAX_PLUGINS_TEST_DIR', MAX_PATH .'/lib/max/Plugin/tests/testdir');

    class TestOfPlugin extends UnitTestCase {

        function TestOfPlugin() {
            $this->UnitTestCase('Plugins test');
        }

        function testFactory() {

        }

        function testGetConfigByFileNameErrors() {
            // file doesn't exists
            Mock::generate('TestErrorHandler');
            $testErrorHandler = new MockTestErrorHandler($this);

            PEAR::setErrorHandling(PEAR_ERROR_CALLBACK, array(&$testErrorHandler, 'handleErrors'));
            $testErrorHandler->expectOnce('handleErrors');

            $ret = MAX_Plugin::getConfigByFileName('someTestFileWhichDoesntExists.conf.ini');
            $this->assertIdentical($ret, false);

            $testErrorHandler->tally();
        }

        function testGetConfigByFileName() {
            $expectedArray = array(
                'key1' => 'val1',
                'key2' => 'val2',
            );
            $ret = MAX_Plugin::getConfigByFileName(MAX_PLUGINS_TEST_DIR . '/plugin.conf.ini');
            $this->assertIdentical($ret, $expectedArray);

            $expectedMultiDimensionalArray = array(
                'section_1' => $expectedArray,
                'section_2' => array('key3' => 'val3'),
            );
            $ret = MAX_Plugin::getConfigByFileName(MAX_PLUGINS_TEST_DIR . '/plugin2.conf.ini', $multiDimensional = true);
            $this->assertIdentical($ret, $expectedMultiDimensionalArray);
        }

        /**
         * something is wrong with mock objects...
         */
        function _REPAIR_ME_testConfig() {
            Mock::generate('MAX_Plugin');

            $module = 'moduleName';
            $package = 'packageName';
            $processSections = false;

            $mockPlugin = &new MockMAX_Plugin($this);
            $mockPlugin->setReturnValue('getConfigByFileName', true);

            $mockPlugin->expectOnce('getConfigByFileName');
            /*
                array(MAX_PATH . "/plugins/{$module}/{$package}/plugin.conf.ini",
                $processSections)
            */
            $ret = $mockPlugin->getConfig($module, $package, null, $commonPackageConfig = true, $processSections);
            $this->assertIdentical($ret, true);
            $mockPlugin->tally();
        }

        function test_getPluginsFromDirectory() {
            $pluginFiles = MAX_Plugin::_getPluginsFilesFromDirectory(MAX_PLUGINS_TEST_DIR, $recursive = false);
            $this->assertIdentical($pluginFiles, array('testdir:test' => MAX_PLUGINS_TEST_DIR.'/test.plugin.php'));

            $pluginFiles = MAX_Plugin::_getPluginsFilesFromDirectory(MAX_PLUGINS_TEST_DIR, $recursive = true);
            $this->assertIdentical($pluginFiles,
                array(
                    'subdir:test2' => MAX_PLUGINS_TEST_DIR.'/subdir/test2.plugin.php',
                    'testdir:test' => MAX_PLUGINS_TEST_DIR.'/test.plugin.php'
                )
            );
        }

        function testGetPlugins() {
        	$recursive = 1;
            $plugins = MAX_Plugin::getPlugins('geotargeting', null, $recursive);

            // it's quite difficult to test so we are using just print_r to test it
            /*
            echo '<pre>';
            print_r($plugins);
            echo '</pre>';
            */
        }

        /**
         * TODO: upgrade simpletest
         */
        function _REPAIR_ME_testGetPlugins() {
            Mock::generate('MAX_Plugin');
            $mockPlugins = new MockMAX_Plugin($this);
            $mockPlugins->setReturnValue('getPluginsFromFolder', true);

            $recursive = true;
            $mockPlugins->expectOnce('getPluginsFromFolder', array(MAX_PATH.'/plugins/moduleName/packageName', $recursive));
            $ret = $mockPlugins->getPlugins('moduleName', 'packageName', $recursive);
            $mockPlugins->tally();
        }

        function testCache() {
            $cacheData = array(1 => 'test', 'some other test' => 123);

            $id = 123456;
            $module =  'testModule';
            $package = 'testPackage';
            $name = 'testName';
            $group = 'testGroup';

            $ret = MAX_Plugin::saveCacheForPlugin($cacheData, $id, $module, $package);
            $this->assertTrue($ret);
            $cache = MAX_Plugin::getCacheForPluginById($id, $module, $package);
            $this->assertEqual($cacheData, $cache);

            // test clean cache
            $ret = MAX_Plugin::cleanPluginCache($module, $package);
            $this->assertTrue($ret);
            $cache = MAX_Plugin::getCacheForPluginById($id, $module, $package);
            $this->assertEqual($cache, false);

            // test cache validality
            $options = array(
                'cacheDir' => MAX_PLUGINS_CACHE . '/' . $module . '/' . $package . '/cache/',
                'automaticSerialization' => true,
                'lifeTime' => 0, // 0 secons
            );
            $ret = MAX_Plugin::saveCacheForPlugin($cacheData, $id, $module, $package, $name, $options, $group);
            $this->assertTrue($ret);

            $cache = MAX_Plugin::getCacheForPluginById($id, $module, $package, $name, $doNotTestCacheValidality = false, $options, $group);
            $this->assertEqual($cache, false);

            // remove test folder
            $this->delDir(MAX_PLUGINS_VAR . '/' . $module);
        }

        /**
         * Remove test folder and all the files from it
         */
        function delDir($dirName) {
           if (empty($dirName)) {
               return true;
           }
           if (file_exists($dirName)) {
               $dir = dir($dirName);
               while ($file = $dir->read()) {
                   if ($file != '.' && $file != '..') {
                       if (is_dir($dirName.'/'.$file)) {
                           $this->delDir($dirName.'/'.$file);
                       } else {
                           @unlink($dirName.'/'.$file) or die('File '.$dirName.'/'.$file.' couldn\'t be deleted, check permissions.');
                       }
                   }
               }
               $dir->close();
               @rmdir($dirName) or die('Folder '.$dirName.' couldn\'t be deleted, check permissions.');
           } else {
               return false;
           }
           return true;
        }

    }

?>