<?php
/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Reports.php 4452 2006-03-13 18:03:17Z roh@m3.net $
*/

require_once MAX_PATH . '/lib/max/Plugin/Common.php';
require_once MAX_PATH . '/www/admin/lib-permissions.inc.php';

/**
 *
 * Plugins_Reports is an abstract class for every Report plugin
 *
 * @package    MaxPlugins
 * @subpackage Reports
 * @author     Radek Maciaszek <radek@m3.net>
 * @author     Robert Hunter <roh@m3.net>
 */
class Plugins_Reports extends MAX_Plugin_Common
{
    var $type;

    /* @var string */
    var $_name;

    /* @var string */
    var $_description;

    /* @var string */
    var $_category;

    /* @var string */
    var $_categoryName;

    /* @var string */
    var $_author;

    /* @var int */
    var $_authorize;

    /* @var array */
    var $_import;

    /**
     * Public info method
     *
     * @abstract
     * @return string A string describing the class.
     */
    function info()
    {
        $this->initInfo();
        return $this->infoArray();
    }


    /**
     * Configure settings for this report.
     *
     * This method should be overridden to set information specific to each report.
     */
    function initInfo()
    {
    }

    function infoArray()
    {
        include_once MAX_PATH . '/lib/max/Plugin/Translation.php';
        MAX_Plugin_Translation::init($this->module, $this->package);

        $plugininfo = array (
            "plugin-name"           => MAX_Plugin_Translation::translate($this->_name, $this->module, $this->package),
            "plugin-description"    => MAX_Plugin_Translation::translate($this->_description, $this->module, $this->package),
            'plugin-category'       => $this->_category,
            'plugin-category-name'  => MAX_Plugin_Translation::translate($this->_categoryName, $this->module, $this->package),
            "plugin-author"         => $this->_author,
            "plugin-export"         => $this->_export,
            "plugin-authorize"      => $this->_authorize,
            "plugin-import"         => $this->_import
        );
        return ($plugininfo);
    }

    /**
     * Execute report calculations and send results to the browser.
     *
     */
    function execute()
    {
        // do nothing by default
    }

    function isAllowedToExecute()
    {
        // Backwards-compatible way of pulling authorization
        $info = $this->info();
        $authorized_user_types = $info['plugin-authorize'];

        $is_allowed = phpAds_isUser($authorized_user_types);
        return $is_allowed;
    }

    /**
     * Should this report show up in a list, given the current context?
     *
     * By default, any report that can be executed can also be displayed.
     * Override this method if you need separate logic.
     */
    function isAllowedToDisplay()
    {
        return $this->isAllowedToExecute();
    }
}

?>
