#!/usr/bin/php -q
<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: maintenance.php 1055 2004-11-30 15:52:35Z andrew $
*/

/**
 * @package    MaxMaintenance
 * @subpackage Tools
 * @author     Andrew Hill <andrew@m3.net>
 *
 * A script file to run to re-generate the AdServer statistics for a given
 * interval, in the event that the raw data tables were incorrect when the 
 * Maintenance Statistics Engine ran.
 *
 * Requires that the start and end dates of the operation interval to be
 * re-generated are defined at the top of the script before being run
 *
 * @param string Requires the hostname to be passed in as a string.
 */
 
/**
 * The operation interval start and end dates.
 */
define('INTERVAL_START', '2005-09-12 04:00:00');
define('INTERVAL_END',   '2005-09-12 04:59:59');

/***************************************************************************/

$path = dirname(__FILE__);
require_once $path . '/../../../init.php';

// Required files
require_once MAX_PATH . '/lib/core/ServiceLocator.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Maintenance.php';
require_once MAX_PATH . '/lib/max/Maintenance/Statistics.php';
require_once "Date.php";

// Create Date objects of the start and end dates, set the "current time"
// to be 5 seconds after the end of the operation interval
$startDate = &new Date(INTERVAL_START);
$endDate   = &new Date(INTERVAL_END);
$nowDate   = &new Date(INTERVAL_END);
$nowDate->addSeconds(5);
$oServiceLocator = &ServiceLocator::instance();
$oServiceLocator->register('now', $nowDate);

// Check start/end dates - note that check is the reverse of normal check:
// if the operation interval is <= 60, must be start/end of an hour, to 
// make sure we update all the operation intervals in the hour, and if
// the operation interval > 60, must be the start/end of an operation
// interval, to make sure we update all the hours in the operation interval.
$datesOkay = true;
$operationInterval = $conf['maintenance']['operation_interval'];
if ($operationInterval <= 60) {
    // Must ensure that only one hour is being summarised
    if (!Maintenance::checkDatesInSameHour($startDate, $endDate)) {
        $datesOkay = false;
    }
    // Now check that the start and end dates are match the start and
    // end of the hour
    $hourStart = &new Date();
    $hourStart->setYear($startDate->getYear());
    $hourStart->setMonth($startDate->getMonth());
    $hourStart->setDay($startDate->getDay());
    $hourStart->setHour($startDate->getHour());
    $hourStart->setMinute('00');
    $hourStart->setSecond('00');
    $hourEnd = &new Date();
    $hourEnd->setYear($endDate->getYear());
    $hourEnd->setMonth($endDate->getMonth());
    $hourEnd->setDay($endDate->getDay());
    $hourEnd->setHour($endDate->getHour());
    $hourEnd->setMinute('59');
    $hourEnd->setSecond('59');
    if (!$startDate->equals($hourStart)) {
        $datesOkay = false;
    }
    if (!$endDate->equals($hourEnd)) {
        $datesOkay = false;
    }
} else {
    // Must ensure that only one operation interval is being summarised
    $operationIntervalID = 
        Maintenance::convertDateRangeToOperationIntervalID($startDate, $endDate, $operationInterval);
    if (is_bool($operationIntervalID) && !$operationIntervalID) {
        $datesOkay = false;
    }
    // Now check that the start and end dates match the start and end
    // of the operation interval
    list($operationIntervalStart, $operationIntervalEnd) =
        Maintenance::convertDateToOperationIntervalStartAndEndDates($startDate, $operationInterval);
    if (!$startDate->equals($operationIntervalStart)) {
        $datesOkay = false;
    }
    if (!$endDate->equals($operationIntervalEnd)) {
        $datesOkay = false;
    }
}
if ($datesOkay == false) {
    echo "\n" . 'Error: The dates set are not valid. See code comments.' . "\n";
    exit();
}

// Give the user a chance to check the dates that will be used
echo 'Regenerating statistics for the range: "' .
     $startDate->format('%Y-%m-%d %H:%M:%S') . '" to "' . 
     $endDate->format('%Y-%m-%d %H:%M:%S') . '"' . "\n";
echo 'Press CTRL-C within 10 seconds to cancel...' . "\n";
sleep(10);

/***************************************************************************/

// Create a Data Access Layer object
$dbh = &MAX_DB::singleton();

// Find the connections (if any) in the data_intermediate_ad_connection table
$query = "
    SELECT
        data_intermediate_ad_connection_id
    FROM
        {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}
    WHERE
        tracker_date_time >= '" . $startDate->format('%Y-%m-%d %H:%M:%S') . "'
        AND tracker_date_time <= '" . $endDate->format('%Y-%m-%d %H:%M:%S') . "'";
$result = $dbh->query($query);

// Delete any variable values that are attached to these connections
while ($row = mysql_fetch_array($result)) {
    $query = "
        DELETE FROM
            {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']}
        WHERE
            data_intermediate_ad_connection_id = {$row['data_intermediate_ad_connection_id']}";
    $innerResult = $dbh->query($query);
}

// Delete any connections in the data_intermediate_ad_connection table
$query = "
    DELETE FROM
        {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}
    WHERE
        tracker_date_time >= '" . $startDate->format('%Y-%m-%d %H:%M:%S') . "'
        AND tracker_date_time <= '" . $endDate->format('%Y-%m-%d %H:%M:%S') . "'";
$result = $dbh->query($query);

// Delete any summary rows from the data_intermediate_ad table
$query = "
    DELETE FROM
        {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
    WHERE
        interval_start = '" . $startDate->format('%Y-%m-%d %H:%M:%S') . "'
        AND interval_end = '" . $endDate->format('%Y-%m-%d %H:%M:%S') . "'";
$result = $dbh->query($query);

// Delete any summary rows from the data_summary_ad_hourly table
$query = "
    DELETE FROM
        {$conf['table']['prefix']}{$conf['table']['data_summary_ad_hourly']}
    WHERE
        day >= '" . $startDate->format('%Y-%m-%d') . "'
        AND hour >= " . $startDate->format('%H') . "
        AND day <= '" . $endDate->format('%Y-%m-%d') . "'
        AND hour <= " . $endDate->format('%H');
$result = $dbh->query($query);

// Delete any impression history data from the data_summary_zone_impression_history table
$query = "
    DELETE FROM
        {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}
    WHERE
        interval_start >= '" . $startDate->format('%Y-%m-%d %H:%M:%S') . "'
        AND interval_end <= '" . $endDate->format('%Y-%m-%d %H:%M:%S') . "'";
$result = $dbh->query($query);

// Delete any impression history data from the data_summary_ad_zone_assoc table
$query = "
    DELETE FROM
        {$conf['table']['prefix']}{$conf['table']['data_summary_ad_zone_assoc']}
    WHERE
        interval_start >= '" . $startDate->format('%Y-%m-%d %H:%M:%S') . "'
        AND interval_end <= '" . $endDate->format('%Y-%m-%d %H:%M:%S') . "'";
$result = $dbh->query($query);

// Ensure emails are not sent due to activation/deactivation effect
$conf['email']['sendMail'] = false;

// Set a date to one second before the operation interval, to be used as the last
// time the stats were updated
$lastUpdated = &new Date(INTERVAL_START);
$lastUpdated->subtractSeconds(1);

// Create the Maintenance_Statistics factory class
$ms = &new Maintenance_Statistics();
foreach ($conf['modules'] as $module => $installed) {
    if ($installed) {
        // Create an appropriate Maintenance_Statistics class
        $oMaintenanceStatistics = $ms->instance($module);
        $oMaintenanceStatistics->setUpdateRequirements($nowDate, $lastUpdated);
        // Step 1: Summarise raw data into the intermediate tables
        $oMaintenanceStatistics->summariseIntermediate();
        // Step 2: Summarise intermediate data into summary tables
        $oMaintenanceStatistics->summariseFinal();
        // If the module is the AdServer module...
        if ($module == 'AdServer') {
            // Optional Step 2.5: Manage activation/deactivation
            //                    of campaigns
            $oMaintenanceStatistics->manageCampaigns();
        }
        // Step 3: Delete old raw data that has been summarised
        $oMaintenanceStatistics->deleteOldData();
        // Step 4: Update the log tables detailing the maintenance statistics run
        $oMaintenanceStatistics->logCompletion();
    }
}

?>
